@@ -1,7 +1,8 @@
-from zope.interface import implements
-from zope.lifecycleevent import ObjectAddedEvent
 from node.ext.directory.interfaces import IFileAddedEvent
+from zope.interface import implementer
+from zope.lifecycleevent import ObjectAddedEvent
 
 
+@implementer(IFileAddedEvent)
 class FileAddedEvent(ObjectAddedEvent):
-    implements(IFileAddedEvent)
+    """Event which gets triggered when file is added to directory."""
